@@ -13,6 +13,7 @@ from fief.db import AsyncSession
 from fief.db.engine import AsyncSession, create_async_session_maker, create_engine
 from fief.db.workspace import get_connection
 from fief.locale import Translations
+from fief.logger import init_audit_logger, logger
 from fief.models import Tenant, User, Workspace
 from fief.paths import EMAIL_TEMPLATES_DIRECTORY
 from fief.repositories import TenantRepository, WorkspaceRepository
@@ -36,11 +37,12 @@ SendTask = Callable[..., None]
 
 
 def send_task(task: dramatiq.Actor, *args, **kwargs):
+    logger.debug("Send task", task=task.actor_name)
     task.send(*args, **kwargs)
 
 
 def get_main_session_task() -> AsyncContextManager[AsyncSession]:
-    main_engine = create_engine(settings.get_database_url())
+    main_engine = create_engine(settings.get_database_connection_parameters())
     return create_async_session_maker(main_engine)()
 
 
@@ -48,7 +50,7 @@ def get_main_session_task() -> AsyncContextManager[AsyncSession]:
 async def get_workspace_session_task(
     workspace: Workspace,
 ) -> AsyncGenerator[AsyncSession, None]:
-    engine = create_engine(workspace.get_database_url())
+    engine = create_engine(workspace.get_database_connection_parameters())
     async with get_connection(engine, workspace.get_schema_name()) as connection:
         async with AsyncSession(bind=connection, expire_on_commit=False) as session:
             yield session
@@ -91,7 +93,12 @@ class TaskBase:
             # Thus, we create one here and set it for future works.
             loop = asyncio.new_event_loop()
             asyncio.set_event_loop(loop)
-        return loop.run_until_complete(self.run(*args, **kwargs))
+
+        init_audit_logger()
+        logger.debug("Start task", task=self.__name__)
+        result = loop.run_until_complete(self.run(*args, **kwargs))
+        logger.debug("Done task", task=self.__name__)
+        return result
 
     async def _get_workspace(self, workspace_id: UUID4) -> Workspace:
         async with self.get_main_session() as session:
